window.Gleam.initSearch([{"doc":"scriptorium","title":"scriptorium","content":"# scriptorium\n\nScriptorium is a simple blog generator for Gleam, using [Lustre](https://hexdocs.pm/lustre) and\n[lustre_ssg](https://hexdocs.pm/lustre_ssg).\n\nScriptorium runs on the JavaScript target and is tested with Node.js.\n\n[![Package Version](https://img.shields.io/hexpm/v/scriptorium)](https://hex.pm/packages/scriptorium)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/scriptorium/)\n\n## Quickstart\n\nTo use Scriptorium, you will need to create a new Gleam project and add Scriptorium as a\ndependency.\n\n```sh\ngleam add scriptorium\n```\n\nTo generate a default blog, use the following in your main file:\n\n```gleam\nimport gleam/result\nimport gleam/option\nimport gleam/io\nimport scriptorium/builder\nimport scriptorium/config.{type Configuration, Configuration}\nimport scriptorium/defaults\n\npub fn main() {\n  let config =\n    defaults.default_config(\n      &quot;My Blog&quot;,\n      &quot;https://my.blog.example/&quot;,\n      &quot;en&quot;,\n      config.Author(\n        &quot;Person McPerson&quot;,\n        option.Some(&quot;person@example.com&quot;),\n        option.Some(&quot;https://fedi.instance.example/@person&quot;),\n      ),\n      &quot;© Person McPerson&quot;,\n    )\n\n  io.debug(build(config))\n}\n\npub fn build(config: Configuration) {\n  // Parse the files\n  use db &lt;- result.try(builder.parse(config))\n  // Compile Markdown into HTML\n  let compiled = builder.compile(db, config)\n  // Render content into Lustre elements\n  let rendered = builder.render(db, compiled, config)\n  // Write rendered content into the filesystem\n  builder.write(rendered, config)\n}\n```\n\nNow you will need to add source files. Create the following directory tree in the root of the project\nfolder:\n\n```\nyour_project\n└── data\n    ├── pages\n    └── posts\n```\n\nIn `./data/posts`, create a file `2024-04-21-hello-world.md` with the following contents:\n\n```markdown\nHello, World!\nmeta\n\nThis is the first blog entry.\n```\n\nThen run `gleam run --target javascript` to build the blog and see what was generated in `./output`.\n\nFor further usage help, see the documentation as described below.\n\n## Documentation\n\n- [User&#39;s Guide](https://nicd.gitlab.io/scriptorium_blog/guide.html)\n- [Scriptorium API reference](https://hexdocs.pm/scriptorium)\n- [Scriptorium Demo Blog](https://nicd.gitlab.io/scriptorium_blog)\n","url":"index.html"},{"doc":"scriptorium","title":"scriptorium","content":"# Changelog\n\n## 2.0.1\n\n- Bumped dependencies to build on the latest stdlib, which is now also required.\n\n## 2.0.0\n\n- Added Gettext support so that the created blog can be translated.\n- Added header `lang` that can set the language of an individual page or post.\n- Added language information to the Atom feed.\n- Split `tags` and `archives` components out of the base layout for easier reuse.\n- Made base layout `pre_render` function public so base layout is easier to customise.\n\n## 1.0.2\n\nAdjusted the title sizing.\n\n## 1.0.1\n\nFix dependency to `lustre_ssg`.\n\n## 1.0.0\n\nInitial release.\n","url":"changelog.html"},{"doc":"scriptorium/models/menu","title":"MenuItem","content":"pub type MenuItem {\n  MenuItem(url: String, name: String)\n}\n A menu item that points to some URL (relative or absolute) and has a name.\nMenuItem(url: String, name: String)\n\n\nSynonyms:\nscriptorium/models/menu.MenuItem\nscriptorium/models/menu MenuItem","url":"scriptorium/models/menu.html#MenuItem"},{"doc":"scriptorium/models/menu","title":"scriptorium/models/menu","content":"","url":"scriptorium/models/menu.html"},{"doc":"scriptorium/models/header","title":"Header","content":"pub type Header =\n  #(String, String)\n A post or page header: a string key and a string value.\n\nSynonyms:\nscriptorium/models/header.Header\nscriptorium/models/header Header","url":"scriptorium/models/header.html#Header"},{"doc":"scriptorium/models/header","title":"scriptorium/models/header","content":"","url":"scriptorium/models/header.html"},{"doc":"scriptorium/models/page","title":"Page","content":"pub type Page {\n  Page(\n    title: String,\n    slug: String,\n    headers: List(Header),\n    content: String,\n  )\n}\n\nPage(\n  title: String,\n  slug: String,\n  headers: List(Header),\n  content: String,\n)\n\n\nSynonyms:\nscriptorium/models/page.Page\nscriptorium/models/page Page","url":"scriptorium/models/page.html#Page"},{"doc":"scriptorium/models/page","title":"scriptorium/models/page","content":" A static page in the blog that is not part of any post lists or archives.","url":"scriptorium/models/page.html"},{"doc":"scriptorium/utils/ints/day","title":"Day","content":"pub opaque type Day\n\n\nSynonyms:\nscriptorium/utils/ints/day.Day\nscriptorium/utils/ints/day Day","url":"scriptorium/utils/ints/day.html#Day"},{"doc":"scriptorium/utils/ints/day","title":"compare","content":"pub fn compare(a: Day, b: Day) -&gt; Order\n\nSynonyms:\nscriptorium/utils/ints/day.compare\nscriptorium/utils/ints/day compare","url":"scriptorium/utils/ints/day.html#compare"},{"doc":"scriptorium/utils/ints/day","title":"from_int","content":"pub fn from_int(value: Int) -&gt; Result(Day, Overflow)\n\nSynonyms:\nscriptorium/utils/ints/day.from_int\nscriptorium/utils/ints/day from_int","url":"scriptorium/utils/ints/day.html#from_int"},{"doc":"scriptorium/utils/ints/day","title":"to_int","content":"pub fn to_int(value: Day) -&gt; Int\n\nSynonyms:\nscriptorium/utils/ints/day.to_int\nscriptorium/utils/ints/day to_int","url":"scriptorium/utils/ints/day.html#to_int"},{"doc":"scriptorium/utils/ints/day","title":"scriptorium/utils/ints/day","content":" A day is a ranged integer from 1 to 31.","url":"scriptorium/utils/ints/day.html"},{"doc":"scriptorium/utils/date","title":"Date","content":"pub type Date {\n  Date(year: Int, month: Month, day: Day)\n}\n A date with 1-indexed years and days.\nDate(year: Int, month: Month, day: Day)\n\n\nSynonyms:\nscriptorium/utils/date.Date\nscriptorium/utils/date Date","url":"scriptorium/utils/date.html#Date"},{"doc":"scriptorium/utils/date","title":"Month","content":"pub type Month {\n  Jan\n  Feb\n  Mar\n  Apr\n  May\n  Jun\n  Jul\n  Aug\n  Sep\n  Oct\n  Nov\n  Dec\n}\n\nJan\n\n\nFeb\n\n\nMar\n\n\nApr\n\n\nMay\n\n\nJun\n\n\nJul\n\n\nAug\n\n\nSep\n\n\nOct\n\n\nNov\n\n\nDec\n\n\nSynonyms:\nscriptorium/utils/date.Month\nscriptorium/utils/date Month","url":"scriptorium/utils/date.html#Month"},{"doc":"scriptorium/utils/date","title":"months","content":"pub const months: List(Month)\n All months in order.\nSynonyms:\nscriptorium/utils/date.months\nscriptorium/utils/date months","url":"scriptorium/utils/date.html#months"},{"doc":"scriptorium/utils/date","title":"compare","content":"pub fn compare(a: Date, b: Date) -&gt; Order\n Compare if `a` is before (lower than) `b`.\nSynonyms:\nscriptorium/utils/date.compare\nscriptorium/utils/date compare","url":"scriptorium/utils/date.html#compare"},{"doc":"scriptorium/utils/date","title":"days_in_month","content":"pub fn days_in_month(month: Month, year: Int) -&gt; Int\n Get the number of days in a month in a given year.\nSynonyms:\nscriptorium/utils/date.days_in_month\nscriptorium/utils/date days_in_month","url":"scriptorium/utils/date.html#days_in_month"},{"doc":"scriptorium/utils/date","title":"format","content":"pub fn format(date: Date, context: Context) -&gt; String\n Format a date as a string.\nSynonyms:\nscriptorium/utils/date.format\nscriptorium/utils/date format","url":"scriptorium/utils/date.html#format"},{"doc":"scriptorium/utils/date","title":"format_iso","content":"pub fn format_iso(date: Date) -&gt; String\n Format a date in the ISO 8601 format.\nSynonyms:\nscriptorium/utils/date.format_iso\nscriptorium/utils/date format_iso","url":"scriptorium/utils/date.html#format_iso"},{"doc":"scriptorium/utils/date","title":"is_valid_date","content":"pub fn is_valid_date(date: Date) -&gt; Bool\n Check if a given date is valid.\nSynonyms:\nscriptorium/utils/date.is_valid_date\nscriptorium/utils/date is_valid_date","url":"scriptorium/utils/date.html#is_valid_date"},{"doc":"scriptorium/utils/date","title":"month_to_int","content":"pub fn month_to_int(month: Month) -&gt; Int\n Convert a month to a 1-indexed int.\nSynonyms:\nscriptorium/utils/date.month_to_int\nscriptorium/utils/date month_to_int","url":"scriptorium/utils/date.html#month_to_int"},{"doc":"scriptorium/utils/date","title":"month_to_short_string","content":"pub fn month_to_short_string(\n  month: Month,\n  context: Context,\n) -&gt; String\n Convert a month to a short month name string.\nSynonyms:\nscriptorium/utils/date.month_to_short_string\nscriptorium/utils/date month_to_short_string","url":"scriptorium/utils/date.html#month_to_short_string"},{"doc":"scriptorium/utils/date","title":"month_to_string","content":"pub fn month_to_string(month: Month, context: Context) -&gt; String\n Convert a month to a month name string.\nSynonyms:\nscriptorium/utils/date.month_to_string\nscriptorium/utils/date month_to_string","url":"scriptorium/utils/date.html#month_to_string"},{"doc":"scriptorium/utils/date","title":"parse_month","content":"pub fn parse_month(month_int: Int) -&gt; Result(Month, Nil)\n Parse an integer into a month.\nSynonyms:\nscriptorium/utils/date.parse_month\nscriptorium/utils/date parse_month","url":"scriptorium/utils/date.html#parse_month"},{"doc":"scriptorium/utils/date","title":"scriptorium/utils/date","content":"","url":"scriptorium/utils/date.html"},{"doc":"scriptorium/utils/ints/hour","title":"Hour","content":"pub opaque type Hour\n\n\nSynonyms:\nscriptorium/utils/ints/hour.Hour\nscriptorium/utils/ints/hour Hour","url":"scriptorium/utils/ints/hour.html#Hour"},{"doc":"scriptorium/utils/ints/hour","title":"compare","content":"pub fn compare(a: Hour, b: Hour) -&gt; Order\n\nSynonyms:\nscriptorium/utils/ints/hour.compare\nscriptorium/utils/ints/hour compare","url":"scriptorium/utils/ints/hour.html#compare"},{"doc":"scriptorium/utils/ints/hour","title":"from_int","content":"pub fn from_int(value: Int) -&gt; Result(Hour, Overflow)\n\nSynonyms:\nscriptorium/utils/ints/hour.from_int\nscriptorium/utils/ints/hour from_int","url":"scriptorium/utils/ints/hour.html#from_int"},{"doc":"scriptorium/utils/ints/hour","title":"to_int","content":"pub fn to_int(value: Hour) -&gt; Int\n\nSynonyms:\nscriptorium/utils/ints/hour.to_int\nscriptorium/utils/ints/hour to_int","url":"scriptorium/utils/ints/hour.html#to_int"},{"doc":"scriptorium/utils/ints/hour","title":"scriptorium/utils/ints/hour","content":" An hour is a ranged integer from 0 to 23.","url":"scriptorium/utils/ints/hour.html"},{"doc":"scriptorium/utils/ints/minute","title":"Minute","content":"pub opaque type Minute\n\n\nSynonyms:\nscriptorium/utils/ints/minute.Minute\nscriptorium/utils/ints/minute Minute","url":"scriptorium/utils/ints/minute.html#Minute"},{"doc":"scriptorium/utils/ints/minute","title":"compare","content":"pub fn compare(a: Minute, b: Minute) -&gt; Order\n\nSynonyms:\nscriptorium/utils/ints/minute.compare\nscriptorium/utils/ints/minute compare","url":"scriptorium/utils/ints/minute.html#compare"},{"doc":"scriptorium/utils/ints/minute","title":"from_int","content":"pub fn from_int(value: Int) -&gt; Result(Minute, Overflow)\n\nSynonyms:\nscriptorium/utils/ints/minute.from_int\nscriptorium/utils/ints/minute from_int","url":"scriptorium/utils/ints/minute.html#from_int"},{"doc":"scriptorium/utils/ints/minute","title":"to_int","content":"pub fn to_int(value: Minute) -&gt; Int\n\nSynonyms:\nscriptorium/utils/ints/minute.to_int\nscriptorium/utils/ints/minute to_int","url":"scriptorium/utils/ints/minute.html#to_int"},{"doc":"scriptorium/utils/ints/minute","title":"scriptorium/utils/ints/minute","content":" A minute is a ranged integer from 0 to 59.","url":"scriptorium/utils/ints/minute.html"},{"doc":"scriptorium/utils/time","title":"Time","content":"pub type Time {\n  Time(hours: Hour, minutes: Minute)\n}\n\nTime(hours: Hour, minutes: Minute)\n\n\nSynonyms:\nscriptorium/utils/time.Time\nscriptorium/utils/time Time","url":"scriptorium/utils/time.html#Time"},{"doc":"scriptorium/utils/time","title":"compare","content":"pub fn compare(a: Time, b: Time) -&gt; Order\n Compare if `a` is before (lower than) than `b`.\nSynonyms:\nscriptorium/utils/time.compare\nscriptorium/utils/time compare","url":"scriptorium/utils/time.html#compare"},{"doc":"scriptorium/utils/time","title":"format","content":"pub fn format(time: Time, context: Context) -&gt; String\n Format a time to a string.\nSynonyms:\nscriptorium/utils/time.format\nscriptorium/utils/time format","url":"scriptorium/utils/time.html#format"},{"doc":"scriptorium/utils/time","title":"format_iso","content":"pub fn format_iso(time: Time) -&gt; String\n Format a time to an `hh:mm` 24 hour string.\nSynonyms:\nscriptorium/utils/time.format_iso\nscriptorium/utils/time format_iso","url":"scriptorium/utils/time.html#format_iso"},{"doc":"scriptorium/utils/time","title":"nil_time","content":"pub fn nil_time() -&gt; Time\n Get a time at hour 0 and minute 0.\nSynonyms:\nscriptorium/utils/time.nil_time\nscriptorium/utils/time nil_time","url":"scriptorium/utils/time.html#nil_time"},{"doc":"scriptorium/utils/time","title":"parse","content":"pub fn parse(str: String) -&gt; Result(Time, Nil)\n Parse a time from an `hh:mm` format string.\nSynonyms:\nscriptorium/utils/time.parse\nscriptorium/utils/time parse","url":"scriptorium/utils/time.html#parse"},{"doc":"scriptorium/utils/time","title":"scriptorium/utils/time","content":"","url":"scriptorium/utils/time.html"},{"doc":"scriptorium/utils/luxon","title":"DateTime","content":"pub type DateTime\n Luxon DateTime.\n\nSynonyms:\nscriptorium/utils/luxon.DateTime\nscriptorium/utils/luxon DateTime","url":"scriptorium/utils/luxon.html#DateTime"},{"doc":"scriptorium/utils/luxon","title":"date_time_in_zone","content":"pub fn date_time_in_zone(\n  date: Date,\n  time: Time,\n  tz: String,\n) -&gt; Result(DateTime, Nil)\n Get a Luxon DateTime in the given timezone.\nSynonyms:\nscriptorium/utils/luxon.date_time_in_zone\nscriptorium/utils/luxon date_time_in_zone","url":"scriptorium/utils/luxon.html#date_time_in_zone"},{"doc":"scriptorium/utils/luxon","title":"to_iso","content":"pub fn to_iso(dt: DateTime) -&gt; String\n Format the DateTime as an ISO 8601 format string.\nSynonyms:\nscriptorium/utils/luxon.to_iso\nscriptorium/utils/luxon to_iso","url":"scriptorium/utils/luxon.html#to_iso"},{"doc":"scriptorium/utils/luxon","title":"utc_now","content":"pub fn utc_now() -&gt; DateTime\n Get the current time as UTC.\nSynonyms:\nscriptorium/utils/luxon.utc_now\nscriptorium/utils/luxon utc_now","url":"scriptorium/utils/luxon.html#utc_now"},{"doc":"scriptorium/utils/luxon","title":"scriptorium/utils/luxon","content":" Bindings to the Luxon library.","url":"scriptorium/utils/luxon.html"},{"doc":"scriptorium/models/post","title":"Post","content":"pub type Post {\n  Post(\n    title: String,\n    slug: String,\n    tags: List(Tag),\n    headers: List(Header),\n    content: String,\n    short_content: Option(String),\n    date: PostedAt,\n    order: Int,\n  )\n}\n\nPost(\n  title: String,\n  slug: String,\n  tags: List(Tag),\n  headers: List(Header),\n  content: String,\n  short_content: Option(String),\n  date: PostedAt,\n  order: Int,\n)\n\nshort_content\n&lt;p&gt;The content before the split, if any&lt;/p&gt;\n\norder\n&lt;p&gt;The post’s order during that day, if there are multiple posts on the same day.&lt;/p&gt;\n\nSynonyms:\nscriptorium/models/post.Post\nscriptorium/models/post Post","url":"scriptorium/models/post.html#Post"},{"doc":"scriptorium/models/post","title":"PostedAt","content":"pub type PostedAt {\n  JustDate(Date)\n  DateTime(date: Date, time: Time, tz: String, luxon: DateTime)\n}\n\nJustDate(Date)\n The post only had date information.\n\nDateTime(date: Date, time: Time, tz: String, luxon: DateTime)\n The post had date, time, and timezone information.\n\nSynonyms:\nscriptorium/models/post.PostedAt\nscriptorium/models/post PostedAt","url":"scriptorium/models/post.html#PostedAt"},{"doc":"scriptorium/models/post","title":"Tag","content":"pub type Tag =\n  String\n A tag is any string of lowercase characters, numbers, dashes, or underscores.\n\nSynonyms:\nscriptorium/models/post.Tag\nscriptorium/models/post Tag","url":"scriptorium/models/post.html#Tag"},{"doc":"scriptorium/models/post","title":"comparator","content":"pub fn comparator(a: Post, b: Post) -&gt; Order\n Compare two posts and get an order between them.\nSynonyms:\nscriptorium/models/post.comparator\nscriptorium/models/post comparator","url":"scriptorium/models/post.html#comparator"},{"doc":"scriptorium/models/post","title":"get_date","content":"pub fn get_date(post: Post) -&gt; Date\n Get the date of the post.\nSynonyms:\nscriptorium/models/post.get_date\nscriptorium/models/post get_date","url":"scriptorium/models/post.html#get_date"},{"doc":"scriptorium/models/post","title":"get_luxon","content":"pub fn get_luxon(post: Post) -&gt; Option(DateTime)\n Get the Luxon datetime of the post, if it exists.\nSynonyms:\nscriptorium/models/post.get_luxon\nscriptorium/models/post get_luxon","url":"scriptorium/models/post.html#get_luxon"},{"doc":"scriptorium/models/post","title":"get_time","content":"pub fn get_time(post: Post) -&gt; Option(Time)\n Get the time of the post, if it exists.\nSynonyms:\nscriptorium/models/post.get_time\nscriptorium/models/post get_time","url":"scriptorium/models/post.html#get_time"},{"doc":"scriptorium/models/post","title":"to_iso8601","content":"pub fn to_iso8601(post: Post) -&gt; String\n Get the post&#39;s date or datetime formatted as an ISO 8601 formatted string.\nSynonyms:\nscriptorium/models/post.to_iso8601\nscriptorium/models/post to_iso8601","url":"scriptorium/models/post.html#to_iso8601"},{"doc":"scriptorium/models/post","title":"scriptorium/models/post","content":" A post in the blog.","url":"scriptorium/models/post.html"},{"doc":"scriptorium/utils/ordered_tree","title":"Comparator","content":"pub type Comparator(a) =\n  fn(a, a) -&gt; Order\n Comparator function to resolve the order of items. Must return `Lt` if the\n first argument is before the second, `Gt` if the opposite, or `Eq` if they\n are equal.\n\nSynonyms:\nscriptorium/utils/ordered_tree.Comparator\nscriptorium/utils/ordered_tree Comparator","url":"scriptorium/utils/ordered_tree.html#Comparator"},{"doc":"scriptorium/utils/ordered_tree","title":"OrderedTree","content":"pub opaque type OrderedTree(a)\n\n\nSynonyms:\nscriptorium/utils/ordered_tree.OrderedTree\nscriptorium/utils/ordered_tree OrderedTree","url":"scriptorium/utils/ordered_tree.html#OrderedTree"},{"doc":"scriptorium/utils/ordered_tree","title":"WalkOrder","content":"pub type WalkOrder {\n  Asc\n  Desc\n}\n Item ordering for when walking through a tree.\nAsc\n\n\nDesc\n\n\nSynonyms:\nscriptorium/utils/ordered_tree.WalkOrder\nscriptorium/utils/ordered_tree WalkOrder","url":"scriptorium/utils/ordered_tree.html#WalkOrder"},{"doc":"scriptorium/utils/ordered_tree","title":"fold","content":"pub fn fold(\n  over tree: OrderedTree(a),\n  from initial: b,\n  order order: WalkOrder,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Fold over the elements in the tree in the given order.\nSynonyms:\nscriptorium/utils/ordered_tree.fold\nscriptorium/utils/ordered_tree fold","url":"scriptorium/utils/ordered_tree.html#fold"},{"doc":"scriptorium/utils/ordered_tree","title":"insert","content":"pub fn insert(tree: OrderedTree(a), item: a) -&gt; OrderedTree(a)\n Insert a new item into the tree.\nSynonyms:\nscriptorium/utils/ordered_tree.insert\nscriptorium/utils/ordered_tree insert","url":"scriptorium/utils/ordered_tree.html#insert"},{"doc":"scriptorium/utils/ordered_tree","title":"length","content":"pub fn length(tree: OrderedTree(a)) -&gt; Int\n Get the amount of items in the tree.\n\n This operation runs in O(n) time.\nSynonyms:\nscriptorium/utils/ordered_tree.length\nscriptorium/utils/ordered_tree length","url":"scriptorium/utils/ordered_tree.html#length"},{"doc":"scriptorium/utils/ordered_tree","title":"new","content":"pub fn new(comparator: fn(a, a) -&gt; Order) -&gt; OrderedTree(a)\n Create a new, empty tree, with the given comparator.\nSynonyms:\nscriptorium/utils/ordered_tree.new\nscriptorium/utils/ordered_tree new","url":"scriptorium/utils/ordered_tree.html#new"},{"doc":"scriptorium/utils/ordered_tree","title":"to_list","content":"pub fn to_list(tree: OrderedTree(a), order: WalkOrder) -&gt; List(a)\n Get the tree as a list in the given list order.\nSynonyms:\nscriptorium/utils/ordered_tree.to_list\nscriptorium/utils/ordered_tree to_list","url":"scriptorium/utils/ordered_tree.html#to_list"},{"doc":"scriptorium/utils/ordered_tree","title":"scriptorium/utils/ordered_tree","content":" An ordered unbalanced tree.\n\n Ordering of items is maintained as new items are inserted into the tree.\n Sort of a replacement for an ordered list. Worst case performance for\n insertion is O(n).","url":"scriptorium/utils/ordered_tree.html"},{"doc":"scriptorium/utils/uniqid","title":"Generator","content":"pub opaque type Generator\n Unique ID generator.\n\nSynonyms:\nscriptorium/utils/uniqid.Generator\nscriptorium/utils/uniqid Generator","url":"scriptorium/utils/uniqid.html#Generator"},{"doc":"scriptorium/utils/uniqid","title":"UniqID","content":"pub type UniqID =\n  BigInt\n A unique ID.\n\nSynonyms:\nscriptorium/utils/uniqid.UniqID\nscriptorium/utils/uniqid UniqID","url":"scriptorium/utils/uniqid.html#UniqID"},{"doc":"scriptorium/utils/uniqid","title":"get","content":"pub fn get(gen: Generator) -&gt; #(BigInt, Generator)\n Get a unique ID and a new generator, that can be used to generate a new ID.\nSynonyms:\nscriptorium/utils/uniqid.get\nscriptorium/utils/uniqid get","url":"scriptorium/utils/uniqid.html#get"},{"doc":"scriptorium/utils/uniqid","title":"new","content":"pub fn new() -&gt; Generator\n Get a new generator.\nSynonyms:\nscriptorium/utils/uniqid.new\nscriptorium/utils/uniqid new","url":"scriptorium/utils/uniqid.html#new"},{"doc":"scriptorium/utils/uniqid","title":"scriptorium/utils/uniqid","content":"","url":"scriptorium/utils/uniqid.html"},{"doc":"scriptorium/models/database","title":"Database","content":"pub opaque type Database\n\n\nSynonyms:\nscriptorium/models/database.Database\nscriptorium/models/database Database","url":"scriptorium/models/database.html#Database"},{"doc":"scriptorium/models/database","title":"MonthPosts","content":"pub type MonthPosts =\n  Dict(Month, OrderedTree(PostWithID))\n Posts organised by month. This is used inside `YearPosts`.\n\nSynonyms:\nscriptorium/models/database.MonthPosts\nscriptorium/models/database MonthPosts","url":"scriptorium/models/database.html#MonthPosts"},{"doc":"scriptorium/models/database","title":"PostID","content":"pub type PostID =\n  UniqID\n Internal post ID, generated automatically.\n\nSynonyms:\nscriptorium/models/database.PostID\nscriptorium/models/database PostID","url":"scriptorium/models/database.html#PostID"},{"doc":"scriptorium/models/database","title":"PostWithID","content":"pub type PostWithID {\n  PostWithID(id: PostID, post: Post)\n}\n\nPostWithID(id: PostID, post: Post)\n\n\nSynonyms:\nscriptorium/models/database.PostWithID\nscriptorium/models/database PostWithID","url":"scriptorium/models/database.html#PostWithID"},{"doc":"scriptorium/models/database","title":"TagPosts","content":"pub type TagPosts =\n  Dict(Tag, OrderedTree(PostWithID))\n All tags and their posts.\n\nSynonyms:\nscriptorium/models/database.TagPosts\nscriptorium/models/database TagPosts","url":"scriptorium/models/database.html#TagPosts"},{"doc":"scriptorium/models/database","title":"YearPosts","content":"pub type YearPosts =\n  Dict(Int, MonthPosts)\n Posts organised by year, containing posts organised by month.\n\nSynonyms:\nscriptorium/models/database.YearPosts\nscriptorium/models/database YearPosts","url":"scriptorium/models/database.html#YearPosts"},{"doc":"scriptorium/models/database","title":"add_page","content":"pub fn add_page(db: Database, page: Page) -&gt; Database\n Add a page into the database.\nSynonyms:\nscriptorium/models/database.add_page\nscriptorium/models/database add_page","url":"scriptorium/models/database.html#add_page"},{"doc":"scriptorium/models/database","title":"add_post","content":"pub fn add_post(db: Database, post: Post) -&gt; Database\n Add a post into the database.\nSynonyms:\nscriptorium/models/database.add_post\nscriptorium/models/database add_post","url":"scriptorium/models/database.html#add_post"},{"doc":"scriptorium/models/database","title":"get_posts_with_ids","content":"pub fn get_posts_with_ids(\n  db: Database,\n  order: WalkOrder,\n) -&gt; List(PostWithID)\n Get all posts in the given order.\nSynonyms:\nscriptorium/models/database.get_posts_with_ids\nscriptorium/models/database get_posts_with_ids","url":"scriptorium/models/database.html#get_posts_with_ids"},{"doc":"scriptorium/models/database","title":"menu","content":"pub fn menu(db: Database) -&gt; List(MenuItem)\n Get menu items.\nSynonyms:\nscriptorium/models/database.menu\nscriptorium/models/database menu","url":"scriptorium/models/database.html#menu"},{"doc":"scriptorium/models/database","title":"new","content":"pub fn new() -&gt; Database\n Create a new empty database.\nSynonyms:\nscriptorium/models/database.new\nscriptorium/models/database new","url":"scriptorium/models/database.html#new"},{"doc":"scriptorium/models/database","title":"pages","content":"pub fn pages(db: Database) -&gt; List(Page)\n Get pages.\nSynonyms:\nscriptorium/models/database.pages\nscriptorium/models/database pages","url":"scriptorium/models/database.html#pages"},{"doc":"scriptorium/models/database","title":"set_menu","content":"pub fn set_menu(db: Database, menu: List(MenuItem)) -&gt; Database\n Set the menu items of the database, replacing any old ones.\nSynonyms:\nscriptorium/models/database.set_menu\nscriptorium/models/database set_menu","url":"scriptorium/models/database.html#set_menu"},{"doc":"scriptorium/models/database","title":"tags","content":"pub fn tags(\n  db: Database,\n) -&gt; Dict(String, OrderedTree(PostWithID))\n Get posts organised by tags.\nSynonyms:\nscriptorium/models/database.tags\nscriptorium/models/database tags","url":"scriptorium/models/database.html#tags"},{"doc":"scriptorium/models/database","title":"years","content":"pub fn years(\n  db: Database,\n) -&gt; Dict(Int, Dict(Month, OrderedTree(PostWithID)))\n Get posts organised by years and months.\nSynonyms:\nscriptorium/models/database.years\nscriptorium/models/database years","url":"scriptorium/models/database.html#years"},{"doc":"scriptorium/models/database","title":"scriptorium/models/database","content":" The database contains all the parsed data from the input files, but not\n processed content.","url":"scriptorium/models/database.html"},{"doc":"scriptorium/utils/marked","title":"Options","content":"pub type Options =\n  Object\n Marked.js options object.\n\nSynonyms:\nscriptorium/utils/marked.Options\nscriptorium/utils/marked Options","url":"scriptorium/utils/marked.html#Options"},{"doc":"scriptorium/utils/marked","title":"default_parse","content":"pub fn default_parse(content: String) -&gt; String\n Parse a string containing Markdown using the default options.\nSynonyms:\nscriptorium/utils/marked.default_parse\nscriptorium/utils/marked default_parse","url":"scriptorium/utils/marked.html#default_parse"},{"doc":"scriptorium/utils/marked","title":"new_options","content":"pub fn new_options() -&gt; Object\n Create a new options object.\nSynonyms:\nscriptorium/utils/marked.new_options\nscriptorium/utils/marked new_options","url":"scriptorium/utils/marked.html#new_options"},{"doc":"scriptorium/utils/marked","title":"parse","content":"pub fn parse(\n  content content: String,\n  options options: Object,\n) -&gt; String\n Parse a string containing Markdown using Marked.js.\nSynonyms:\nscriptorium/utils/marked.parse\nscriptorium/utils/marked parse","url":"scriptorium/utils/marked.html#parse"},{"doc":"scriptorium/utils/marked","title":"set_header_ids","content":"pub fn set_header_ids(options: Object, ids: Bool) -&gt; Object\n Set the `headerIds` option on or off.\nSynonyms:\nscriptorium/utils/marked.set_header_ids\nscriptorium/utils/marked set_header_ids","url":"scriptorium/utils/marked.html#set_header_ids"},{"doc":"scriptorium/utils/marked","title":"set_header_prefix","content":"pub fn set_header_prefix(\n  options: Object,\n  prefix: String,\n) -&gt; Object\n Set the `headerPrefix` option.\nSynonyms:\nscriptorium/utils/marked.set_header_prefix\nscriptorium/utils/marked set_header_prefix","url":"scriptorium/utils/marked.html#set_header_prefix"},{"doc":"scriptorium/utils/marked","title":"set_mangle","content":"pub fn set_mangle(options: Object, do_mangle: Bool) -&gt; Object\n Set the `mangle` option on or off.\nSynonyms:\nscriptorium/utils/marked.set_mangle\nscriptorium/utils/marked set_mangle","url":"scriptorium/utils/marked.html#set_mangle"},{"doc":"scriptorium/utils/marked","title":"scriptorium/utils/marked","content":" Bindings to the marked.js library.","url":"scriptorium/utils/marked.html"},{"doc":"scriptorium/compiler","title":"CompileDatabase","content":"pub type CompileDatabase {\n  CompileDatabase(\n    posts: Dict(PostID, CompiledPost),\n    pages: List(CompiledPage),\n  )\n}\n Structure where the compilation results are stored.\nCompileDatabase(\n  posts: Dict(PostID, CompiledPost),\n  pages: List(CompiledPage),\n)\n\n\nSynonyms:\nscriptorium/compiler.CompileDatabase\nscriptorium/compiler CompileDatabase","url":"scriptorium/compiler.html#CompileDatabase"},{"doc":"scriptorium/compiler","title":"CompiledPage","content":"pub type CompiledPage {\n  CompiledPage(orig: Page, content: String)\n}\n A page and its compiled content.\nCompiledPage(orig: Page, content: String)\n\n\nSynonyms:\nscriptorium/compiler.CompiledPage\nscriptorium/compiler CompiledPage","url":"scriptorium/compiler.html#CompiledPage"},{"doc":"scriptorium/compiler","title":"CompiledPost","content":"pub type CompiledPost {\n  CompiledPost(orig: Post, content: PostContent)\n}\n A post and its compiled content.\nCompiledPost(orig: Post, content: PostContent)\n\n\nSynonyms:\nscriptorium/compiler.CompiledPost\nscriptorium/compiler CompiledPost","url":"scriptorium/compiler.html#CompiledPost"},{"doc":"scriptorium/compiler","title":"Compiler","content":"pub type Compiler =\n  fn(String, Database) -&gt; String\n A function to compile the given string content into an HTML string.\n\nSynonyms:\nscriptorium/compiler.Compiler\nscriptorium/compiler Compiler","url":"scriptorium/compiler.html#Compiler"},{"doc":"scriptorium/compiler","title":"PostContent","content":"pub type PostContent {\n  PostContent(full: String, short: option.Option(String))\n}\n Compiled post content: strings that contain HTML.\nPostContent(full: String, short: option.Option(String))\n\n\nSynonyms:\nscriptorium/compiler.PostContent\nscriptorium/compiler PostContent","url":"scriptorium/compiler.html#PostContent"},{"doc":"scriptorium/compiler","title":"compile","content":"pub fn compile(\n  db: Database,\n  compiler: fn(String, Database) -&gt; String,\n) -&gt; CompileDatabase\n Compile contents of the database using the given compiler.\nSynonyms:\nscriptorium/compiler.compile\nscriptorium/compiler compile","url":"scriptorium/compiler.html#compile"},{"doc":"scriptorium/compiler","title":"compile_pages","content":"pub fn compile_pages(\n  db: Database,\n  compiler: fn(String, Database) -&gt; String,\n) -&gt; List(CompiledPage)\n Compile all pages in the database using the given compiler.\nSynonyms:\nscriptorium/compiler.compile_pages\nscriptorium/compiler compile_pages","url":"scriptorium/compiler.html#compile_pages"},{"doc":"scriptorium/compiler","title":"compile_posts","content":"pub fn compile_posts(\n  db: Database,\n  compiler: fn(String, Database) -&gt; String,\n) -&gt; Dict(BigInt, CompiledPost)\n Compile all posts in the database using the given compiler.\nSynonyms:\nscriptorium/compiler.compile_posts\nscriptorium/compiler compile_posts","url":"scriptorium/compiler.html#compile_posts"},{"doc":"scriptorium/compiler","title":"default_compiler","content":"pub fn default_compiler(content: String, db: Database) -&gt; String\n The default compiler that uses Marked.js with default settings.\nSynonyms:\nscriptorium/compiler.default_compiler\nscriptorium/compiler default_compiler","url":"scriptorium/compiler.html#default_compiler"},{"doc":"scriptorium/compiler","title":"scriptorium/compiler","content":" Compiling means turning post and page content into HTML. By default this\n content is Markdown that is compiled with Marked.js.","url":"scriptorium/compiler.html"},{"doc":"scriptorium/paths","title":"PathConfiguration","content":"pub type PathConfiguration {\n  PathConfiguration(\n    root: String,\n    index: String,\n    single_post: fn(Post) -&gt; String,\n    page: fn(Page) -&gt; String,\n    tag: fn(String) -&gt; String,\n    year: fn(Int) -&gt; String,\n    month: fn(Int, Month) -&gt; String,\n    list_page: fn(String, Int) -&gt; String,\n    html: fn(String) -&gt; String,\n    feed: String,\n    feed_file: String,\n  )\n}\n The path configuration controls where files will be located and where links\n will point to.\nPathConfiguration(\n  root: String,\n  index: String,\n  single_post: fn(Post) -&gt; String,\n  page: fn(Page) -&gt; String,\n  tag: fn(String) -&gt; String,\n  year: fn(Int) -&gt; String,\n  month: fn(Int, Month) -&gt; String,\n  list_page: fn(String, Int) -&gt; String,\n  html: fn(String) -&gt; String,\n  feed: String,\n  feed_file: String,\n)\n\nroot\n&lt;p&gt;The root path where the blog will be accessible. With starting slash but\nwithout trailing slash, e.g. &lt;code&gt;/scriptorium_blog&lt;/code&gt;. Note that if the blog is\naccessible without a subpath, this value should be &lt;code&gt;&quot;&quot;&lt;/code&gt;.&lt;/p&gt;\n\nindex\n&lt;p&gt;The index path. Note that the first page of the index is always written\ninto &lt;code&gt;&quot;/&quot;&lt;/code&gt;, meaning &lt;code&gt;index.html&lt;/code&gt;. This path is used for the rest of the\npages, e.g. &lt;code&gt;&quot;/wibble&quot;&lt;/code&gt; would result in &lt;code&gt;/wibble/2.html&lt;/code&gt;,\n&lt;code&gt;/wibble/3.html&lt;/code&gt; and so on.&lt;/p&gt;\n\nsingle_post\n&lt;p&gt;Path to a single post.&lt;/p&gt;\n\npage\n&lt;p&gt;Path to a page.&lt;/p&gt;\n\ntag\n&lt;p&gt;Path to a tag archive.&lt;/p&gt;\n\nyear\n&lt;p&gt;Path to a year archive.&lt;/p&gt;\n\nmonth\n&lt;p&gt;Path to a month archive of a given year.&lt;/p&gt;\n\nlist_page\n&lt;p&gt;List page path: given the original path such as &lt;code&gt;/tag/wibble&lt;/code&gt; as a\nstring and the page number, forms the final path.&lt;/p&gt;\n\nhtml\n&lt;p&gt;HTML path: Append (or don’t) the &lt;code&gt;.html&lt;/code&gt; extension to the given path.\nIf you are using fancy URLs without extensions, override this to do\nnothing.&lt;/p&gt;\n\nfeed\n&lt;p&gt;Path to the feed as it is accessible from the browser.&lt;/p&gt;\n\nfeed_file\n&lt;p&gt;Path and file name of the feed file that will be written, &lt;em&gt;without&lt;/em&gt; the\nfile extension! E.g. &lt;code&gt;/feed&lt;/code&gt; will create a file &lt;code&gt;/feed.xml&lt;/code&gt;.&lt;/p&gt;\n\nSynonyms:\nscriptorium/paths.PathConfiguration\nscriptorium/paths PathConfiguration","url":"scriptorium/paths.html#PathConfiguration"},{"doc":"scriptorium/paths","title":"default_feed","content":"pub const default_feed: String\n The default path where the feed is accessible when hosted.\nSynonyms:\nscriptorium/paths.default_feed\nscriptorium/paths default_feed","url":"scriptorium/paths.html#default_feed"},{"doc":"scriptorium/paths","title":"default_feed_file","content":"pub const default_feed_file: String\n The default filename where the feed is written.\nSynonyms:\nscriptorium/paths.default_feed_file\nscriptorium/paths default_feed_file","url":"scriptorium/paths.html#default_feed_file"},{"doc":"scriptorium/paths","title":"default_index","content":"pub const default_index: String\n The default index path.\nSynonyms:\nscriptorium/paths.default_index\nscriptorium/paths default_index","url":"scriptorium/paths.html#default_index"},{"doc":"scriptorium/paths","title":"defaults","content":"pub const defaults: PathConfiguration\n Default path configuration.\nSynonyms:\nscriptorium/paths.defaults\nscriptorium/paths defaults","url":"scriptorium/paths.html#defaults"},{"doc":"scriptorium/paths","title":"default_html","content":"pub fn default_html(path: String) -&gt; String\n Get path with the .html extension.\nSynonyms:\nscriptorium/paths.default_html\nscriptorium/paths default_html","url":"scriptorium/paths.html#default_html"},{"doc":"scriptorium/paths","title":"default_list_page","content":"pub fn default_list_page(path: String, page: Int) -&gt; String\n Get the given list path with a page number.\n\n The first page does not get any appended page number.\nSynonyms:\nscriptorium/paths.default_list_page\nscriptorium/paths default_list_page","url":"scriptorium/paths.html#default_list_page"},{"doc":"scriptorium/paths","title":"default_month_archive","content":"pub fn default_month_archive(year: Int, month: Month) -&gt; String\n Month archive path in the format `/archive/2024/05`.\nSynonyms:\nscriptorium/paths.default_month_archive\nscriptorium/paths default_month_archive","url":"scriptorium/paths.html#default_month_archive"},{"doc":"scriptorium/paths","title":"default_page","content":"pub fn default_page(page: Page) -&gt; String\n Page path in the format `/slug`.\nSynonyms:\nscriptorium/paths.default_page\nscriptorium/paths default_page","url":"scriptorium/paths.html#default_page"},{"doc":"scriptorium/paths","title":"default_single_post","content":"pub fn default_single_post(post: Post) -&gt; String\n Post path in the format `/2024/12/31/slug`.\nSynonyms:\nscriptorium/paths.default_single_post\nscriptorium/paths default_single_post","url":"scriptorium/paths.html#default_single_post"},{"doc":"scriptorium/paths","title":"default_tag","content":"pub fn default_tag(tag: String) -&gt; String\n Tag path in the format `/tag/tag`.\nSynonyms:\nscriptorium/paths.default_tag\nscriptorium/paths default_tag","url":"scriptorium/paths.html#default_tag"},{"doc":"scriptorium/paths","title":"default_year_archive","content":"pub fn default_year_archive(year: Int) -&gt; String\n Year archive path in the format `/archive/2024`.\nSynonyms:\nscriptorium/paths.default_year_archive\nscriptorium/paths default_year_archive","url":"scriptorium/paths.html#default_year_archive"},{"doc":"scriptorium/paths","title":"scriptorium/paths","content":" Path configuration controls where files are generated and how links are\n formed.","url":"scriptorium/paths.html"},{"doc":"scriptorium/rendering/database","title":"RenderDatabase","content":"pub type RenderDatabase {\n  RenderDatabase(\n    single_posts: List(RenderedSinglePost),\n    pages: List(RenderedPage),\n    index_pages: List(RenderedListPage),\n    tag_pages: Dict(String, List(RenderedListPage)),\n    year_pages: Dict(Int, List(RenderedListPage)),\n    month_pages: Dict(#(Int, Month), List(RenderedListPage)),\n    feed: Element(Nil),\n  )\n}\n\nRenderDatabase(\n  single_posts: List(RenderedSinglePost),\n  pages: List(RenderedPage),\n  index_pages: List(RenderedListPage),\n  tag_pages: Dict(String, List(RenderedListPage)),\n  year_pages: Dict(Int, List(RenderedListPage)),\n  month_pages: Dict(#(Int, Month), List(RenderedListPage)),\n  feed: Element(Nil),\n)\n\nsingle_posts\n&lt;p&gt;Individual posts.&lt;/p&gt;\n\npages\n&lt;p&gt;Individual pages.&lt;/p&gt;\n\nindex_pages\n&lt;p&gt;“Index” list pages, meaning the main post flow.&lt;/p&gt;\n\ntag_pages\n&lt;p&gt;Tag list pages.&lt;/p&gt;\n\nyear_pages\n&lt;p&gt;Year list pages.&lt;/p&gt;\n\nmonth_pages\n&lt;p&gt;Month list pages.&lt;/p&gt;\n\nfeed\n&lt;p&gt;The feed (corresponding to the main post flow).&lt;/p&gt;\n\nSynonyms:\nscriptorium/rendering/database.RenderDatabase\nscriptorium/rendering/database RenderDatabase","url":"scriptorium/rendering/database.html#RenderDatabase"},{"doc":"scriptorium/rendering/database","title":"RenderedListPage","content":"pub type RenderedListPage {\n  ListPage(page: Int, content: Element(Nil))\n}\n A list page&#39;s page number and the page&#39;s content.\nListPage(page: Int, content: Element(Nil))\n\n\nSynonyms:\nscriptorium/rendering/database.RenderedListPage\nscriptorium/rendering/database RenderedListPage","url":"scriptorium/rendering/database.html#RenderedListPage"},{"doc":"scriptorium/rendering/database","title":"RenderedPage","content":"pub type RenderedPage {\n  RenderedPage(page: Page, content: Element(Nil))\n}\n A page and its rendered content.\nRenderedPage(page: Page, content: Element(Nil))\n\n\nSynonyms:\nscriptorium/rendering/database.RenderedPage\nscriptorium/rendering/database RenderedPage","url":"scriptorium/rendering/database.html#RenderedPage"},{"doc":"scriptorium/rendering/database","title":"RenderedSinglePost","content":"pub type RenderedSinglePost {\n  RenderedSinglePost(orig: Post, content: Element(Nil))\n}\n A post and its rendered content.\nRenderedSinglePost(orig: Post, content: Element(Nil))\n\n\nSynonyms:\nscriptorium/rendering/database.RenderedSinglePost\nscriptorium/rendering/database RenderedSinglePost","url":"scriptorium/rendering/database.html#RenderedSinglePost"},{"doc":"scriptorium/rendering/database","title":"scriptorium/rendering/database","content":" The render database stores the rendered posts and pages.","url":"scriptorium/rendering/database.html"},{"doc":"scriptorium/rendering/views","title":"BaseView","content":"pub type BaseView =\n  fn(Element(Nil), List(Element(Nil)), String) -&gt; Element(Nil)\n The base view renders the base page layout.\n\n The three arguments are:\n - The inner content to render in the layout.\n - Extra elements to put inside `&lt;head&gt;`.\n - Text to add as a prefix to the `&lt;title&gt;` element.\n\nSynonyms:\nscriptorium/rendering/views.BaseView\nscriptorium/rendering/views BaseView","url":"scriptorium/rendering/views.html#BaseView"},{"doc":"scriptorium/rendering/views","title":"FeedView","content":"pub type FeedView =\n  fn(List(CompiledPost)) -&gt; Element(Nil)\n View to render the RSS or Atom feed.\n\nSynonyms:\nscriptorium/rendering/views.FeedView\nscriptorium/rendering/views FeedView","url":"scriptorium/rendering/views.html#FeedView"},{"doc":"scriptorium/rendering/views","title":"ListInfo","content":"pub type ListInfo {\n  ListInfo(\n    root_path: String,\n    current_page: Int,\n    total_pages: Int,\n    posts: List(CompiledPost),\n    extra_header: Element(Nil),\n  )\n}\n Information passed for list pages.\nListInfo(\n  root_path: String,\n  current_page: Int,\n  total_pages: Int,\n  posts: List(CompiledPost),\n  extra_header: Element(Nil),\n)\n\nroot_path\n&lt;p&gt;The path to prefix before the page number. E.g. &lt;code&gt;/index&lt;/code&gt; and the resulting path would then be &lt;code&gt;/index/2&lt;/code&gt;.&lt;/p&gt;\n\ncurrent_page\n&lt;p&gt;The page number of the current page being rendered.&lt;/p&gt;\n\ntotal_pages\n&lt;p&gt;The amount of pages in the current list.&lt;/p&gt;\n\nposts\n&lt;p&gt;Posts on this page.&lt;/p&gt;\n\nextra_header\n&lt;p&gt;Any extra content to put on top of the page before the posts.&lt;/p&gt;\n\nSynonyms:\nscriptorium/rendering/views.ListInfo\nscriptorium/rendering/views ListInfo","url":"scriptorium/rendering/views.html#ListInfo"},{"doc":"scriptorium/rendering/views","title":"ListPageView","content":"pub type ListPageView =\n  fn(ListInfo) -&gt; Element(Nil)\n View to render a list page. A list page is a page with many posts in a list.\n\nSynonyms:\nscriptorium/rendering/views.ListPageView\nscriptorium/rendering/views ListPageView","url":"scriptorium/rendering/views.html#ListPageView"},{"doc":"scriptorium/rendering/views","title":"MetaView","content":"pub type MetaView =\n  fn(PageType) -&gt; List(Element(Nil))\n The meta view renders meta tags such as OpenGraph based on the page information.\n\nSynonyms:\nscriptorium/rendering/views.MetaView\nscriptorium/rendering/views MetaView","url":"scriptorium/rendering/views.html#MetaView"},{"doc":"scriptorium/rendering/views","title":"PageType","content":"pub type PageType {\n  Post(post.Post)\n  Page(page.Page)\n  Other(title: String, description: String)\n}\n Types of pages in the blog.\nPost(post.Post)\n Individual post.\n\nPage(page.Page)\n Individual page.\n\nOther(title: String, description: String)\n Any other page.\n\nSynonyms:\nscriptorium/rendering/views.PageType\nscriptorium/rendering/views PageType","url":"scriptorium/rendering/views.html#PageType"},{"doc":"scriptorium/rendering/views","title":"PageView","content":"pub type PageView =\n  fn(CompiledPage) -&gt; Element(Nil)\n View to render an individual page.\n\nSynonyms:\nscriptorium/rendering/views.PageView\nscriptorium/rendering/views PageView","url":"scriptorium/rendering/views.html#PageView"},{"doc":"scriptorium/rendering/views","title":"SinglePostView","content":"pub type SinglePostView =\n  fn(CompiledPost) -&gt; Element(Nil)\n View to render an individual post.\n\nSynonyms:\nscriptorium/rendering/views.SinglePostView\nscriptorium/rendering/views SinglePostView","url":"scriptorium/rendering/views.html#SinglePostView"},{"doc":"scriptorium/rendering/views","title":"scriptorium/rendering/views","content":"","url":"scriptorium/rendering/views.html"},{"doc":"scriptorium/config","title":"Author","content":"pub type Author {\n  Author(\n    name: String,\n    email: option.Option(String),\n    url: option.Option(String),\n  )\n}\n Author related configuration.\nAuthor(\n  name: String,\n  email: option.Option(String),\n  url: option.Option(String),\n)\n\nname\n&lt;p&gt;Name of the author.&lt;/p&gt;\n\nemail\n&lt;p&gt;Email address of the author, used in the feed’s author information.&lt;/p&gt;\n\nurl\n&lt;p&gt;Website URL of the author, used in the feed’s author information and\nadded as a &lt;code&gt;rel=&quot;me&quot;&lt;/code&gt; link in the base layout.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Author\nscriptorium/config Author","url":"scriptorium/config.html#Author"},{"doc":"scriptorium/config","title":"Compiling","content":"pub type Compiling {\n  Compiling(\n    database_compiler: fn(Database, Compiler) -&gt; CompileDatabase,\n    item_compiler: Compiler,\n  )\n}\n Compiling related configuration.\nCompiling(\n  database_compiler: fn(Database, Compiler) -&gt; CompileDatabase,\n  item_compiler: Compiler,\n)\n\ndatabase_compiler\n&lt;p&gt;The compiler to use for compiling the database.&lt;/p&gt;\n\nitem_compiler\n&lt;p&gt;The compiler to use for compiling individual items.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Compiling\nscriptorium/config Compiling","url":"scriptorium/config.html#Compiling"},{"doc":"scriptorium/config","title":"Configuration","content":"pub type Configuration {\n  Configuration(\n    blog_name: String,\n    blog_url: String,\n    author: Author,\n    l10n: Localization,\n    compiling: Compiling,\n    rendering: Rendering,\n    paths: PathConfiguration,\n    parser: Parser,\n    writer: Writer,\n    output_path: String,\n  )\n}\n\nConfiguration(\n  blog_name: String,\n  blog_url: String,\n  author: Author,\n  l10n: Localization,\n  compiling: Compiling,\n  rendering: Rendering,\n  paths: PathConfiguration,\n  parser: Parser,\n  writer: Writer,\n  output_path: String,\n)\n\nblog_name\n&lt;p&gt;Name of the blog.&lt;/p&gt;\n\nblog_url\n&lt;p&gt;Absolute URL of the blog, this is where you are deploying it.&lt;/p&gt;\n\noutput_path\n&lt;p&gt;The folder to write the output into.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Configuration\nscriptorium/config Configuration","url":"scriptorium/config.html#Configuration"},{"doc":"scriptorium/config","title":"Localization","content":"pub type Localization {\n  Localization(language: String, context: Context)\n}\n Localization related configuration.\nLocalization(language: String, context: Context)\n\nlanguage\n&lt;p&gt;Language code of the blog, meaning the language of the content you are\nwriting. The language code must be according to\n&lt;a href=&quot;https://datatracker.ietf.org/doc/html/rfc5646&quot;&gt;https://datatracker.ietf.org/doc/html/rfc5646&lt;/a&gt;.&lt;/p&gt;\n\ncontext\n&lt;p&gt;Context to use for gettext operations for translating built-in strings.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Localization\nscriptorium/config Localization","url":"scriptorium/config.html#Localization"},{"doc":"scriptorium/config","title":"ParseError","content":"pub type ParseError {\n  ParseError(err: String)\n}\n An error occurred when parsing input files.\nParseError(err: String)\n\n\nSynonyms:\nscriptorium/config.ParseError\nscriptorium/config ParseError","url":"scriptorium/config.html#ParseError"},{"doc":"scriptorium/config","title":"Parser","content":"pub type Parser =\n  fn(Configuration) -&gt; Result(Database, ParseError)\n The parser\n\nSynonyms:\nscriptorium/config.Parser\nscriptorium/config Parser","url":"scriptorium/config.html#Parser"},{"doc":"scriptorium/config","title":"Renderer","content":"pub type Renderer =\n  fn(Database, CompileDatabase, Configuration) -&gt; RenderDatabase\n Renders the content of the database into HTML.\n\nSynonyms:\nscriptorium/config.Renderer\nscriptorium/config Renderer","url":"scriptorium/config.html#Renderer"},{"doc":"scriptorium/config","title":"Rendering","content":"pub type Rendering {\n  Rendering(\n    renderer: Renderer,\n    views: Views,\n    copyright: String,\n    posts_per_page: Int,\n    posts_in_feed: Int,\n  )\n}\n Rendering related configuration.\nRendering(\n  renderer: Renderer,\n  views: Views,\n  copyright: String,\n  posts_per_page: Int,\n  posts_in_feed: Int,\n)\n\nrenderer\n&lt;p&gt;The renderer to use.&lt;/p&gt;\n\nviews\n&lt;p&gt;The view generators to use.&lt;/p&gt;\n\ncopyright\n&lt;p&gt;The copyright statement of the blog, used in the footer and the feed.&lt;/p&gt;\n\nposts_per_page\n&lt;p&gt;How many posts to show per page.&lt;/p&gt;\n\nposts_in_feed\n&lt;p&gt;How many posts to render in the feed.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Rendering\nscriptorium/config Rendering","url":"scriptorium/config.html#Rendering"},{"doc":"scriptorium/config","title":"Views","content":"pub type Views {\n  Views(\n    base: fn(Database, Configuration) -&gt; BaseView,\n    meta: fn(Database, Configuration) -&gt; MetaView,\n    single_post_full: fn(Database, Configuration) -&gt;\n      SinglePostView,\n    single_post_list: fn(Database, Configuration) -&gt;\n      SinglePostView,\n    page: fn(Database, Configuration) -&gt; PageView,\n    list_page: fn(Database, Configuration) -&gt; ListPageView,\n    feed: fn(Database, Configuration) -&gt; FeedView,\n  )\n}\n View generators for the blog. These take the database and configuration and\n must return a view function that is used for rendering.\n\n See the `scriptorium/rendering/views` documentation for descriptions of the\n individual views.\nViews(\n  base: fn(Database, Configuration) -&gt; BaseView,\n  meta: fn(Database, Configuration) -&gt; MetaView,\n  single_post_full: fn(Database, Configuration) -&gt; SinglePostView,\n  single_post_list: fn(Database, Configuration) -&gt; SinglePostView,\n  page: fn(Database, Configuration) -&gt; PageView,\n  list_page: fn(Database, Configuration) -&gt; ListPageView,\n  feed: fn(Database, Configuration) -&gt; FeedView,\n)\n\nsingle_post_full\n&lt;p&gt;View for a single post that is rendered on its own.&lt;/p&gt;\n\nsingle_post_list\n&lt;p&gt;View for a single post rendered as part of a list.&lt;/p&gt;\n\nSynonyms:\nscriptorium/config.Views\nscriptorium/config Views","url":"scriptorium/config.html#Views"},{"doc":"scriptorium/config","title":"WriteError","content":"pub type WriteError {\n  WriteError(err: String)\n}\n An error occurred when writing the rendered results into files.\nWriteError(err: String)\n\n\nSynonyms:\nscriptorium/config.WriteError\nscriptorium/config WriteError","url":"scriptorium/config.html#WriteError"},{"doc":"scriptorium/config","title":"Writer","content":"pub type Writer =\n  fn(RenderDatabase, Configuration) -&gt; Result(Nil, WriteError)\n Writes the rendered HTML into files.\n\nSynonyms:\nscriptorium/config.Writer\nscriptorium/config Writer","url":"scriptorium/config.html#Writer"},{"doc":"scriptorium/config","title":"scriptorium/config","content":" The configuration is the main way to customize Scriptorium&#39;s behaviour.","url":"scriptorium/config.html"},{"doc":"scriptorium/builder","title":"BuildError","content":"pub type BuildError {\n  ParseError(err: config.ParseError)\n  WriteError(err: config.WriteError)\n}\n Something failed when building the blog.\nParseError(err: config.ParseError)\n\n\nWriteError(err: config.WriteError)\n\n\nSynonyms:\nscriptorium/builder.BuildError\nscriptorium/builder BuildError","url":"scriptorium/builder.html#BuildError"},{"doc":"scriptorium/builder","title":"compile","content":"pub fn compile(\n  db: Database,\n  config: Configuration,\n) -&gt; CompileDatabase\n Compile the post and page content into HTML strings.\nSynonyms:\nscriptorium/builder.compile\nscriptorium/builder compile","url":"scriptorium/builder.html#compile"},{"doc":"scriptorium/builder","title":"parse","content":"pub fn parse(\n  config: Configuration,\n) -&gt; Result(Database, BuildError)\n Parse the blog&#39;s input files.\nSynonyms:\nscriptorium/builder.parse\nscriptorium/builder parse","url":"scriptorium/builder.html#parse"},{"doc":"scriptorium/builder","title":"render","content":"pub fn render(\n  db: Database,\n  compiled: CompileDatabase,\n  config: Configuration,\n) -&gt; RenderDatabase\n Render the content into HTML pages.\nSynonyms:\nscriptorium/builder.render\nscriptorium/builder render","url":"scriptorium/builder.html#render"},{"doc":"scriptorium/builder","title":"write","content":"pub fn write(\n  posts: RenderDatabase,\n  config: Configuration,\n) -&gt; Result(Nil, BuildError)\n Write the render database into files.\nSynonyms:\nscriptorium/builder.write\nscriptorium/builder write","url":"scriptorium/builder.html#write"},{"doc":"scriptorium/builder","title":"scriptorium/builder","content":" The builder contains convenience functions to interface with the different\n parts of scriptorium, using the configuration to control what is done.","url":"scriptorium/builder.html"},{"doc":"scriptorium/utils/priv","title":"path","content":"pub fn path() -&gt; String\n Get the path to the `priv` directory of `scriptorium`.\nSynonyms:\nscriptorium/utils/priv.path\nscriptorium/utils/priv path","url":"scriptorium/utils/priv.html#path"},{"doc":"scriptorium/utils/priv","title":"scriptorium/utils/priv","content":"","url":"scriptorium/utils/priv.html"},{"doc":"scriptorium/l10n","title":"load_builtins","content":"pub fn load_builtins() -&gt; Database\n Load builtin translations and return a translation database containing them.\nSynonyms:\nscriptorium/l10n.load_builtins\nscriptorium/l10n load_builtins","url":"scriptorium/l10n.html#load_builtins"},{"doc":"scriptorium/l10n","title":"scriptorium/l10n","content":"","url":"scriptorium/l10n.html"},{"doc":"scriptorium/parser/common","title":"ParseError","content":"pub type ParseError {\n  EmptyFile\n  HeaderMissing\n  MalformedFilename\n  YearNotInt\n  MonthNotInt\n  DayNotInt\n  InvalidDate\n  MalformedHeader(header: String)\n}\n An error that occurred when parsing content.\nEmptyFile\n\n\nHeaderMissing\n\n\nMalformedFilename\n\n\nYearNotInt\n\n\nMonthNotInt\n\n\nDayNotInt\n\n\nInvalidDate\n\n\nMalformedHeader(header: String)\n\n\nSynonyms:\nscriptorium/parser/common.ParseError\nscriptorium/parser/common ParseError","url":"scriptorium/parser/common.html#ParseError"},{"doc":"scriptorium/parser/common","title":"filename_postfix","content":"pub const filename_postfix: String\n The default file extension for source files.\nSynonyms:\nscriptorium/parser/common.filename_postfix\nscriptorium/parser/common filename_postfix","url":"scriptorium/parser/common.html#filename_postfix"},{"doc":"scriptorium/parser/common","title":"parse_header","content":"pub fn parse_header(\n  header: String,\n) -&gt; Result(#(String, String), ParseError)\n Parse given line as a header.\nSynonyms:\nscriptorium/parser/common.parse_header\nscriptorium/parser/common parse_header","url":"scriptorium/parser/common.html#parse_header"},{"doc":"scriptorium/parser/common","title":"parse_headers","content":"pub fn parse_headers(\n  headers: List(String),\n) -&gt; Result(List(#(String, String)), ParseError)\n Parse given lines as headers.\nSynonyms:\nscriptorium/parser/common.parse_headers\nscriptorium/parser/common parse_headers","url":"scriptorium/parser/common.html#parse_headers"},{"doc":"scriptorium/parser/common","title":"try","content":"pub fn try(\n  value: Result(a, b),\n  error: c,\n  if_ok: fn(a) -&gt; Result(d, c),\n) -&gt; Result(d, c)\n If the `value` is `Ok`, run `if_ok`, otherwise return `error`.\nSynonyms:\nscriptorium/parser/common.try\nscriptorium/parser/common try","url":"scriptorium/parser/common.html#try"},{"doc":"scriptorium/parser/common","title":"scriptorium/parser/common","content":"","url":"scriptorium/parser/common.html"},{"doc":"scriptorium/parser/menu","title":"parse","content":"pub fn parse(content: String) -&gt; Result(List(MenuItem), Nil)\n Parse the content and return menu items.\nSynonyms:\nscriptorium/parser/menu.parse\nscriptorium/parser/menu parse","url":"scriptorium/parser/menu.html#parse"},{"doc":"scriptorium/parser/menu","title":"scriptorium/parser/menu","content":"","url":"scriptorium/parser/menu.html"},{"doc":"scriptorium/parser/page","title":"parse","content":"pub fn parse(\n  filename: String,\n  contents: String,\n) -&gt; Result(Page, ParseError)\n Parse page from file data.\nSynonyms:\nscriptorium/parser/page.parse\nscriptorium/parser/page parse","url":"scriptorium/parser/page.html#parse"},{"doc":"scriptorium/parser/page","title":"scriptorium/parser/page","content":"","url":"scriptorium/parser/page.html"},{"doc":"scriptorium/parser/post","title":"filename_regex","content":"pub const filename_regex: String\n Post filenames must match this regex.\nSynonyms:\nscriptorium/parser/post.filename_regex\nscriptorium/parser/post filename_regex","url":"scriptorium/parser/post.html#filename_regex"},{"doc":"scriptorium/parser/post","title":"parse","content":"pub fn parse(\n  filename: String,\n  contents: String,\n) -&gt; Result(Post, ParseError)\n Parse post from file data.\nSynonyms:\nscriptorium/parser/post.parse\nscriptorium/parser/post parse","url":"scriptorium/parser/post.html#parse"},{"doc":"scriptorium/parser/post","title":"scriptorium/parser/post","content":"","url":"scriptorium/parser/post.html"},{"doc":"scriptorium/parser","title":"default_parse","content":"pub fn default_parse(\n  config: Configuration,\n) -&gt; Result(Database, ParseError)\n The default parser.\nSynonyms:\nscriptorium/parser.default_parse\nscriptorium/parser default_parse","url":"scriptorium/parser.html#default_parse"},{"doc":"scriptorium/parser","title":"parse_menu","content":"pub fn parse_menu(\n  db: Database,\n  file: String,\n  config: Configuration,\n) -&gt; Result(Database, ParseError)\n Parse the menu from the given file into the database.\nSynonyms:\nscriptorium/parser.parse_menu\nscriptorium/parser parse_menu","url":"scriptorium/parser.html#parse_menu"},{"doc":"scriptorium/parser","title":"parse_pages","content":"pub fn parse_pages(\n  db: Database,\n  path: String,\n) -&gt; Result(Database, ParseError)\n Parse pages from the given path into the database.\nSynonyms:\nscriptorium/parser.parse_pages\nscriptorium/parser parse_pages","url":"scriptorium/parser.html#parse_pages"},{"doc":"scriptorium/parser","title":"parse_posts","content":"pub fn parse_posts(\n  db: Database,\n  path: String,\n) -&gt; Result(Database, ParseError)\n Parse posts from the given path into the database.\nSynonyms:\nscriptorium/parser.parse_posts\nscriptorium/parser parse_posts","url":"scriptorium/parser.html#parse_posts"},{"doc":"scriptorium/parser","title":"scriptorium/parser","content":" Parsing reads the input files into the database.","url":"scriptorium/parser.html"},{"doc":"scriptorium/renderer","title":"Views","content":"pub type Views {\n  Views(\n    base: BaseView,\n    meta: MetaView,\n    single_post_full: SinglePostView,\n    page: PageView,\n    list_page: ListPageView,\n    feed: FeedView,\n  )\n}\n Helper struct to pass all the used views to the rendering functions.\nViews(\n  base: BaseView,\n  meta: MetaView,\n  single_post_full: SinglePostView,\n  page: PageView,\n  list_page: ListPageView,\n  feed: FeedView,\n)\n\nsingle_post_full\n&lt;p&gt;View for a single post rendered on its own.&lt;/p&gt;\n\nSynonyms:\nscriptorium/renderer.Views\nscriptorium/renderer Views","url":"scriptorium/renderer.html#Views"},{"doc":"scriptorium/renderer","title":"render","content":"pub fn render(\n  db: Database,\n  compiled: CompileDatabase,\n  config: Configuration,\n) -&gt; RenderDatabase\n Render the database and compiled content using the configuration.\nSynonyms:\nscriptorium/renderer.render\nscriptorium/renderer render","url":"scriptorium/renderer.html#render"},{"doc":"scriptorium/renderer","title":"render_pages","content":"pub fn render_pages(\n  db: Database,\n  compiled_pages: List(CompiledPage),\n  views: Views,\n) -&gt; List(RenderedPage)\n\nSynonyms:\nscriptorium/renderer.render_pages\nscriptorium/renderer render_pages","url":"scriptorium/renderer.html#render_pages"},{"doc":"scriptorium/renderer","title":"render_posts","content":"pub fn render_posts(\n  db: Database,\n  post_contents: Dict(BigInt, CompiledPost),\n  views: Views,\n) -&gt; List(RenderedSinglePost)\n\nSynonyms:\nscriptorium/renderer.render_posts\nscriptorium/renderer render_posts","url":"scriptorium/renderer.html#render_posts"},{"doc":"scriptorium/renderer","title":"scriptorium/renderer","content":" The renderer&#39;s job is to render compiled content into HTML. By default this\n means Lustre elements that can be later stringified.","url":"scriptorium/renderer.html"},{"doc":"scriptorium/rendering/views/archives","title":"view","content":"pub fn view(db: Database, config: Configuration) -&gt; Element(a)\n\nSynonyms:\nscriptorium/rendering/views/archives.view\nscriptorium/rendering/views/archives view","url":"scriptorium/rendering/views/archives.html#view"},{"doc":"scriptorium/rendering/views/archives","title":"scriptorium/rendering/views/archives","content":" The archives component renders all the years and months where there are\n posts as nested unordered lists.","url":"scriptorium/rendering/views/archives.html"},{"doc":"scriptorium/rendering/views/tags","title":"view","content":"pub fn view(db: Database, config: Configuration) -&gt; Element(a)\n\nSynonyms:\nscriptorium/rendering/views/tags.view\nscriptorium/rendering/views/tags view","url":"scriptorium/rendering/views/tags.html#view"},{"doc":"scriptorium/rendering/views/tags","title":"scriptorium/rendering/views/tags","content":" The tags component renders tags of the database as a tag cloud with tags of\n varying sizes as an unordered list.","url":"scriptorium/rendering/views/tags.html"},{"doc":"scriptorium/rendering/views/base","title":"PreRendered","content":"pub type PreRendered {\n  PreRendered(tags: Element(Nil), archives: Element(Nil))\n}\n The base view pre-renders some content once, so that it can be reused for every render.\nPreRendered(tags: Element(Nil), archives: Element(Nil))\n\n\nSynonyms:\nscriptorium/rendering/views/base.PreRendered\nscriptorium/rendering/views/base PreRendered","url":"scriptorium/rendering/views/base.html#PreRendered"},{"doc":"scriptorium/rendering/views/base","title":"generate","content":"pub fn generate(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(Element(Nil), List(Element(Nil)), String) -&gt; Element(Nil)\n\nSynonyms:\nscriptorium/rendering/views/base.generate\nscriptorium/rendering/views/base generate","url":"scriptorium/rendering/views/base.html#generate"},{"doc":"scriptorium/rendering/views/base","title":"pre_render","content":"pub fn pre_render(\n  db: Database,\n  config: Configuration,\n  tags: fn(Database, Configuration) -&gt; Element(Nil),\n  archives: fn(Database, Configuration) -&gt; Element(Nil),\n) -&gt; PreRendered\n Pre-render the tag and archive elements using the given tags and archives\n components.\nSynonyms:\nscriptorium/rendering/views/base.pre_render\nscriptorium/rendering/views/base pre_render","url":"scriptorium/rendering/views/base.html#pre_render"},{"doc":"scriptorium/rendering/views/base","title":"scriptorium/rendering/views/base","content":"","url":"scriptorium/rendering/views/base.html"},{"doc":"scriptorium/rendering/views/feed","title":"generate","content":"pub fn generate(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(List(CompiledPost)) -&gt; Element(a)\n\nSynonyms:\nscriptorium/rendering/views/feed.generate\nscriptorium/rendering/views/feed generate","url":"scriptorium/rendering/views/feed.html#generate"},{"doc":"scriptorium/rendering/views/feed","title":"scriptorium/rendering/views/feed","content":"","url":"scriptorium/rendering/views/feed.html"},{"doc":"scriptorium/rendering/views/nav","title":"view","content":"pub fn view(\n  list_info: ListInfo,\n  root_path: String,\n  config: Configuration,\n) -&gt; Element(a)\n\nSynonyms:\nscriptorium/rendering/views/nav.view\nscriptorium/rendering/views/nav view","url":"scriptorium/rendering/views/nav.html#view"},{"doc":"scriptorium/rendering/views/nav","title":"scriptorium/rendering/views/nav","content":"","url":"scriptorium/rendering/views/nav.html"},{"doc":"scriptorium/rendering/views/list_page","title":"generate","content":"pub fn generate(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(ListInfo) -&gt; Element(Nil)\n\nSynonyms:\nscriptorium/rendering/views/list_page.generate\nscriptorium/rendering/views/list_page generate","url":"scriptorium/rendering/views/list_page.html#generate"},{"doc":"scriptorium/rendering/views/list_page","title":"scriptorium/rendering/views/list_page","content":"","url":"scriptorium/rendering/views/list_page.html"},{"doc":"scriptorium/rendering/views/meta","title":"generate","content":"pub fn generate(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(PageType) -&gt; List(Element(a))\n\nSynonyms:\nscriptorium/rendering/views/meta.generate\nscriptorium/rendering/views/meta generate","url":"scriptorium/rendering/views/meta.html#generate"},{"doc":"scriptorium/rendering/views/meta","title":"scriptorium/rendering/views/meta","content":"","url":"scriptorium/rendering/views/meta.html"},{"doc":"scriptorium/rendering/views/page","title":"generate","content":"pub fn generate(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(CompiledPage) -&gt; Element(a)\n\nSynonyms:\nscriptorium/rendering/views/page.generate\nscriptorium/rendering/views/page generate","url":"scriptorium/rendering/views/page.html#generate"},{"doc":"scriptorium/rendering/views/page","title":"scriptorium/rendering/views/page","content":"","url":"scriptorium/rendering/views/page.html"},{"doc":"scriptorium/rendering/views/single_post","title":"full_view","content":"pub fn full_view(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(CompiledPost) -&gt; Element(Nil)\n Generate a view that renders a full post.\nSynonyms:\nscriptorium/rendering/views/single_post.full_view\nscriptorium/rendering/views/single_post full_view","url":"scriptorium/rendering/views/single_post.html#full_view"},{"doc":"scriptorium/rendering/views/single_post","title":"list_view","content":"pub fn list_view(\n  db: Database,\n  config: Configuration,\n) -&gt; fn(CompiledPost) -&gt; Element(Nil)\n Generate a view that renders a post that&#39;s inside of a list.\nSynonyms:\nscriptorium/rendering/views/single_post.list_view\nscriptorium/rendering/views/single_post list_view","url":"scriptorium/rendering/views/single_post.html#list_view"},{"doc":"scriptorium/rendering/views/single_post","title":"scriptorium/rendering/views/single_post","content":"","url":"scriptorium/rendering/views/single_post.html"},{"doc":"scriptorium/writer","title":"write","content":"pub fn write(\n  db: RenderDatabase,\n  config: Configuration,\n) -&gt; Result(Nil, WriteError)\n Write the rendered content into the filesystem using lustre_ssg.\nSynonyms:\nscriptorium/writer.write\nscriptorium/writer write","url":"scriptorium/writer.html#write"},{"doc":"scriptorium/writer","title":"scriptorium/writer","content":" The writer takes rendered content and writes it into the filesystem.","url":"scriptorium/writer.html"},{"doc":"scriptorium/defaults","title":"default_config","content":"pub fn default_config(\n  blog_name: String,\n  blog_url: String,\n  language: String,\n  author: Author,\n  copyright: String,\n) -&gt; Configuration\n Get a sensible default configuration based on the given arguments.\nSynonyms:\nscriptorium/defaults.default_config\nscriptorium/defaults default_config","url":"scriptorium/defaults.html#default_config"},{"doc":"scriptorium/defaults","title":"scriptorium/defaults","content":" This module contains default configurations that can be used to create a\n blog quickly.","url":"scriptorium/defaults.html"}]);